@@ -10,7 +10,7 @@ from tlz import sliding_window
 
 from ..base import tokenize
 from ..highlevelgraph import HighLevelGraph
-from ..utils import derived_from
+from ..utils import cached_cumsum, derived_from
 from . import chunk
 from .core import (
     Array,
@@ -19,13 +19,13 @@ from .core import (
     blockwise,
     broadcast_arrays,
     broadcast_to,
-    cached_cumsum,
     concatenate,
     normalize_chunks,
     stack,
 )
+from .numpy_compat import _numpy_120
 from .ufunc import greater_equal, rint
-from .utils import AxisError, meta_from_array
+from .utils import meta_from_array
 from .wrap import empty, full, ones, zeros
 
 
@@ -325,7 +325,7 @@ def linspace(
         return Array(dsk, name, chunks, dtype=dtype)
 
 
-def arange(*args, **kwargs):
+def arange(*args, chunks="auto", like=None, dtype=None, **kwargs):
     """
     Return evenly spaced values from `start` to `stop` with step size `step`.
 
@@ -348,8 +348,12 @@ def arange(*args, **kwargs):
     chunks :  int
         The number of samples on each block. Note that the last block will have
         fewer samples if ``len(array) % chunks != 0``.
+        Defaults to "auto" which will automatically determine chunk sizes.
     dtype : numpy.dtype
         Output dtype. Omit to infer it from start, stop, step
+        Defaults to ``None``.
+    like : array type or ``None``
+        Array to extract meta from. Defaults to ``None``.
 
     Returns
     -------
@@ -376,14 +380,10 @@ def arange(*args, **kwargs):
         """
         )
 
-    chunks = kwargs.pop("chunks", "auto")
-
     num = int(max(np.ceil((stop - start) / step), 0))
 
-    like = kwargs.pop("like", None)
     meta = meta_from_array(like) if like is not None else None
 
-    dtype = kwargs.pop("dtype", None)
     if dtype is None:
         dtype = np.arange(start, stop, step * num if num else step).dtype
 
@@ -414,9 +414,8 @@ def arange(*args, **kwargs):
 
 
 @derived_from(np)
-def meshgrid(*xi, **kwargs):
-    indexing = kwargs.pop("indexing", "xy")
-    sparse = bool(kwargs.pop("sparse", False))
+def meshgrid(*xi, sparse=False, indexing="xy", **kwargs):
+    sparse = bool(sparse)
 
     if "copy" in kwargs:
         raise NotImplementedError("`copy` not supported")
@@ -584,9 +583,7 @@ def diag(v):
             raise ValueError("Array must be 1d or 2d only")
         return Array(dsk, name, chunks, meta=meta)
     if not isinstance(v, Array):
-        raise TypeError(
-            "v must be a dask array or numpy array, got {0}".format(type(v))
-        )
+        raise TypeError(f"v must be a dask array or numpy array, got {type(v)}")
     if v.ndim != 1:
         if v.chunks[0] == v.chunks[1]:
             dsk = {
@@ -627,7 +624,7 @@ def diagonal(a, offset=0, axis1=0, axis2=1):
             t = ndim + axis
             if t < 0:
                 msg = "{}: axis {} is out of bounds for array of dimension {}"
-                raise AxisError(msg.format(name, axis, ndim))
+                raise np.AxisError(msg.format(name, axis, ndim))
             axis = t
         return axis
 
@@ -658,7 +655,7 @@ def diagonal(a, offset=0, axis1=0, axis2=1):
             chunk_offsets[-1].append(k)
 
     dsk = {}
-    idx_set = set(range(a.ndim)) - set([axis1, axis2])
+    idx_set = set(range(a.ndim)) - {axis1, axis2}
     n1 = len(a.chunks[axis1])
     n2 = len(a.chunks[axis2])
     for idx in product(*(range(len(a.chunks[i])) for i in idx_set)):
@@ -683,7 +680,10 @@ def diagonal(a, offset=0, axis1=0, axis2=1):
 
 
 @derived_from(np)
-def tri(N, M=None, k=0, dtype=float, chunks="auto", like=None):
+def tri(N, M=None, k=0, dtype=float, chunks="auto", *, like=None):
+    if not _numpy_120 and like is not None:
+        raise RuntimeError("The use of ``like`` required NumPy >= 1.20")
+
     _min_int = np.lib.twodim_base._min_int
 
     if M is None:
@@ -1133,7 +1133,7 @@ def pad(array, pad_width, mode="constant", **kwargs):
     try:
         unsupported_kwargs = set(kwargs) - set(allowed_kwargs[mode])
     except KeyError as e:
-        raise ValueError("mode '{}' is not supported".format(mode)) from e
+        raise ValueError(f"mode '{mode}' is not supported") from e
     if unsupported_kwargs:
         raise ValueError(
             "unsupported keyword arguments for mode '{}': {}".format(
