@@ -1,20 +1,13 @@
+import json
 import os
+
 import pandas as pd
 import pytest
-import json
-
-try:
-    import lzma
-except ImportError:
-    try:
-        import backports.lzma as lzma
-    except ImportError:
-        lzma = None
 
+import dask
 import dask.dataframe as dd
 from dask.dataframe.utils import assert_eq
-from dask.utils import tmpfile, tmpdir
-
+from dask.utils import tmpdir, tmpfile
 
 df = pd.DataFrame({"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]})
 ddf = dd.from_pandas(df, npartitions=2)
@@ -91,6 +84,25 @@ def test_write_json_basic(orient):
         assert_eq(out, df)
 
 
+def test_to_json_with_get():
+    from dask.multiprocessing import get as mp_get
+
+    flag = [False]
+
+    def my_get(*args, **kwargs):
+        flag[0] = True
+        return mp_get(*args, **kwargs)
+
+    df = pd.DataFrame({"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]})
+    ddf = dd.from_pandas(df, npartitions=2)
+
+    with tmpdir() as dn:
+        ddf.to_json(dn, compute_kwargs={"scheduler": my_get})
+        assert flag[0]
+        result = dd.read_json(os.path.join(dn, "*"))
+        assert_eq(result, df, check_index=False)
+
+
 def test_read_json_error():
     with tmpfile("json") as f:
         with pytest.raises(ValueError):
@@ -106,7 +118,7 @@ def test_read_chunked(block):
         fn = os.path.join(path, "1.json")
         df.to_json(fn, orient="records", lines=True)
         d = dd.read_json(fn, blocksize=block, sample=10)
-        assert (d.npartitions > 1) or (block > 50)
+        assert (d.npartitions > 1) or (block > 30)
         assert_eq(d, df, check_index=False)
 
 
@@ -124,3 +136,17 @@ def test_read_json_inferred_compression():
         dd.to_json(ddf, fn, compression="gzip")
         actual = dd.read_json(fn)
         assert_eq(df, actual.compute(), check_index=False)
+
+
+def test_to_json_results():
+    with tmpfile("json") as f:
+        paths = ddf.to_json(f)
+        assert paths == [os.path.join(f, f"{n}.part") for n in range(ddf.npartitions)]
+
+    with tmpfile("json") as f:
+        list_of_delayed = ddf.to_json(f, compute=False)
+        paths = dask.compute(*list_of_delayed)
+        # this is a tuple rather than a list since it's the output of dask.compute
+        assert paths == tuple(
+            os.path.join(f, f"{n}.part") for n in range(ddf.npartitions)
+        )
