@@ -6,7 +6,7 @@ import pytest
 
 import dask.dataframe as dd
 from dask.base import compute_as_if_collection
-from dask.dataframe._compat import tm
+from dask.dataframe._compat import PANDAS_GT_140, tm
 from dask.dataframe.core import _Frame
 from dask.dataframe.methods import concat
 from dask.dataframe.multi import (
@@ -335,7 +335,7 @@ def test_merge_asof_left_on_right_index(
     b = dd.from_pandas(B, npartitions=2)
 
     if unknown_divisions:
-        a.divisions = [None] * len(a.divisions)
+        a.divisions = (None,) * len(a.divisions)
 
     C = pd.merge_asof(
         A,
@@ -368,7 +368,7 @@ def test_merge_asof_left_on_right_index(
             b = dd.from_pandas(B, npartitions=nparts)
 
             if unknown_divisions:
-                a.divisions = [None] * len(a.divisions)
+                a.divisions = (None,) * len(a.divisions)
 
             C = pd.merge_asof(
                 A,
@@ -2009,6 +2009,22 @@ def test_concat_datetimeindex():
     assert_eq(result, expected)
 
 
+def check_with_warning(dask_obj, dask_append, pandas_obj, pandas_append):
+    with pytest.warns(None) as record:
+        expected = pandas_obj.append(pandas_append)
+        result = dask_obj.append(dask_append)
+        assert_eq(result, expected)
+
+    if PANDAS_GT_140:
+        for w in record:
+            assert w.category == FutureWarning
+            assert "append method is deprecated" in str(w.message)
+    else:
+        assert not record
+
+    return result
+
+
 def test_append():
     df = pd.DataFrame({"a": [1, 2, 3, 4, 5, 6], "b": [1, 2, 3, 4, 5, 6]})
     df2 = pd.DataFrame(
@@ -2024,15 +2040,6 @@ def test_append():
 
     s = pd.Series([7, 8], name=6, index=["a", "b"])
 
-    def check_with_warning(dask_obj, dask_append, pandas_obj, pandas_append):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", FutureWarning)
-            expected = pandas_obj.append(pandas_append)
-
-            result = dask_obj.append(dask_append)
-
-        assert_eq(result, expected)
-
     check_with_warning(ddf, s, df, s)
     check_with_warning(ddf, ddf2, df, df2)
     check_with_warning(ddf.a, ddf2.a, df.a, df2.a)
@@ -2057,6 +2064,7 @@ def test_append2():
     }
     meta = make_meta({"a": "i8", "b": "i8"}, parent_meta=pd.DataFrame())
     ddf1 = dd.DataFrame(dsk, "x", meta, [None, None])
+    df1 = ddf1.compute()
 
     dsk = {
         ("y", 0): pd.DataFrame({"a": [10, 20, 30], "b": [40, 50, 60]}),
@@ -2064,6 +2072,7 @@ def test_append2():
         ("y", 2): pd.DataFrame({"a": [70, 80, 90], "b": [0, 0, 0]}),
     }
     ddf2 = dd.DataFrame(dsk, "y", meta, [None, None])
+    df2 = ddf2.compute()
 
     dsk = {
         ("y", 0): pd.DataFrame({"b": [10, 20, 30], "c": [40, 50, 60]}),
@@ -2071,29 +2080,22 @@ def test_append2():
     }
     meta = make_meta({"b": "i8", "c": "i8"}, parent_meta=pd.DataFrame())
     ddf3 = dd.DataFrame(dsk, "y", meta, [None, None])
+    df3 = ddf3.compute()
 
-    assert_eq(ddf1.append(ddf2), ddf1.compute().append(ddf2.compute(), sort=False))
-    assert_eq(ddf2.append(ddf1), ddf2.compute().append(ddf1.compute(), sort=False))
+    check_with_warning(ddf1, ddf2, df1, df2)
+    check_with_warning(ddf2, ddf1, df2, df1)
 
     # different columns
-    assert_eq(ddf1.append(ddf3), ddf1.compute().append(ddf3.compute(), sort=False))
-    assert_eq(ddf3.append(ddf1), ddf3.compute().append(ddf1.compute(), sort=False))
+    check_with_warning(ddf1, ddf3, df1, df3)
+    check_with_warning(ddf3, ddf1, df3, df1)
 
     # Dask + pandas
-    assert_eq(
-        ddf1.append(ddf2.compute()), ddf1.compute().append(ddf2.compute(), sort=False)
-    )
-    assert_eq(
-        ddf2.append(ddf1.compute()), ddf2.compute().append(ddf1.compute(), sort=False)
-    )
+    check_with_warning(ddf1, df2, df1, df2)
+    check_with_warning(ddf2, df1, df2, df1)
 
     # different columns
-    assert_eq(
-        ddf1.append(ddf3.compute()), ddf1.compute().append(ddf3.compute(), sort=False)
-    )
-    assert_eq(
-        ddf3.append(ddf1.compute()), ddf3.compute().append(ddf1.compute(), sort=False)
-    )
+    check_with_warning(ddf1, df3, df1, df3)
+    check_with_warning(ddf3, df1, df3, df1)
 
 
 def test_append_categorical():
@@ -2131,18 +2133,16 @@ def test_append_categorical():
             )
         ddf1, ddf2 = dframes
 
-        res = ddf1.append(ddf2)
-        assert_eq(res, df1.append(df2))
+        res = check_with_warning(ddf1, ddf2, df1, df2)
+
         assert has_known_categories(res.index) == known
         assert has_known_categories(res.y) == known
 
-        res = ddf1.y.append(ddf2.y)
-        assert_eq(res, df1.y.append(df2.y))
+        res = check_with_warning(ddf1.y, ddf2.y, df1.y, df2.y)
         assert has_known_categories(res.index) == known
         assert has_known_categories(res) == known
 
-        res = ddf1.index.append(ddf2.index)
-        assert_eq(res, df1.index.append(df2.index))
+        res = check_with_warning(ddf1.index, ddf2.index, df1.index, df2.index)
         assert has_known_categories(res) == known
 
 
@@ -2150,9 +2150,8 @@ def test_append_lose_divisions():
     df = pd.DataFrame({"x": [1, 2, 3, 4]}, index=[1, 2, 3, 4])
     ddf = dd.from_pandas(df, npartitions=2)
 
-    ddf2 = ddf.append(ddf)
-    df2 = df.append(df)
-    assert_eq(ddf2, df2)
+    res = check_with_warning(ddf, ddf, df, df)
+    assert res.known_divisions is False
 
 
 def test_singleton_divisions():
