@@ -4,7 +4,7 @@ import pytest
 
 import dask.dataframe as dd
 from dask.dataframe._compat import tm
-from dask.dataframe.utils import assert_eq, make_meta_util
+from dask.dataframe.utils import assert_eq, make_meta
 
 
 @pytest.mark.parametrize(
@@ -59,14 +59,10 @@ def test_get_dummies_kwargs():
     ds = dd.from_pandas(s, 2)
     res = dd.get_dummies(ds, prefix="X", prefix_sep="-")
     assert_eq(res, exp)
-    tm.assert_index_equal(res.columns, pd.Index(["X-1", "X-2", "X-3", "X-4"]))
 
     exp = pd.get_dummies(s, drop_first=True)
-
-    ds = dd.from_pandas(s, 2)
     res = dd.get_dummies(ds, drop_first=True)
     assert_eq(res, exp)
-    tm.assert_index_equal(res.columns, exp.columns)
 
     # nan
     s = pd.Series([1, 1, 1, 2, np.nan, 3, np.nan, 5], dtype="category")
@@ -75,17 +71,16 @@ def test_get_dummies_kwargs():
     ds = dd.from_pandas(s, 2)
     res = dd.get_dummies(ds)
     assert_eq(res, exp)
-    tm.assert_index_equal(res.columns, exp.columns)
 
     # dummy_na
     exp = pd.get_dummies(s, dummy_na=True)
-
-    ds = dd.from_pandas(s, 2)
     res = dd.get_dummies(ds, dummy_na=True)
     assert_eq(res, exp)
-    tm.assert_index_equal(res.columns, pd.Index([1, 2, 3, 5, np.nan]))
 
 
+@pytest.mark.filterwarnings(
+    "ignore:In a future version, passing a SparseArray:FutureWarning"
+)  # https://github.com/pandas-dev/pandas/issues/45618
 def test_get_dummies_sparse():
     s = pd.Series(pd.Categorical(["a", "b", "a"], categories=["a", "b", "c"]))
     ds = dd.from_pandas(s, 2)
@@ -103,6 +98,9 @@ def test_get_dummies_sparse():
     assert pd.api.types.is_sparse(res.a_a.compute())
 
 
+@pytest.mark.filterwarnings(
+    "ignore:In a future version, passing a SparseArray:FutureWarning"
+)  # https://github.com/pandas-dev/pandas/issues/45618
 def test_get_dummies_sparse_mix():
     df = pd.DataFrame(
         {
@@ -149,7 +147,7 @@ def test_get_dummies_errors():
     # unknown categories
     df = pd.DataFrame({"x": list("abcbc"), "y": list("bcbcb")})
     ddf = dd.from_pandas(df, npartitions=2)
-    ddf._meta = make_meta_util(
+    ddf._meta = make_meta(
         {"x": "category", "y": "category"}, parent_meta=pd.DataFrame()
     )
 
@@ -259,7 +257,7 @@ def test_pivot_table_errors():
     assert msg in str(err.value)
 
     # unknown categories
-    ddf._meta = make_meta_util(
+    ddf._meta = make_meta(
         {"A": object, "B": float, "C": "category"}, parent_meta=pd.DataFrame()
     )
     msg = "'columns' must have known categories"
