@@ -4,12 +4,14 @@ import numpy as np
 import pandas as pd
 import pytest
 
+import dask
 import dask.dataframe as dd
 from dask.dataframe._compat import tm
 from dask.dataframe.core import apply_and_enforce
 from dask.dataframe.utils import (
     PANDAS_GT_120,
     UNKNOWN_CATEGORIES,
+    assert_eq,
     check_matching_columns,
     check_meta,
     is_dataframe_like,
@@ -20,6 +22,7 @@ from dask.dataframe.utils import (
     raise_on_meta_error,
     shard_df_on_index,
 )
+from dask.local import get_sync
 
 
 def test_shard_df_on_index():
@@ -81,14 +84,18 @@ def test_make_meta():
     assert meta.name == "a"
 
     # With index
+    idx = pd.Index([1, 2], name="foo")
     meta = make_meta(
         {"a": "i8", "b": "i4"},
-        index=pd.Int64Index([1, 2], name="foo"),
+        index=idx,
     )
-    assert isinstance(meta.index, pd.Int64Index)
+    assert type(meta.index) is type(idx)
+    assert meta.index.dtype == "int64"
     assert len(meta.index) == 0
-    meta = make_meta(("a", "i8"), index=pd.Int64Index([1, 2], name="foo"))
-    assert isinstance(meta.index, pd.Int64Index)
+
+    meta = make_meta(("a", "i8"), index=idx)
+    assert type(meta.index) is type(idx)
+    assert meta.index.dtype == "int64"
     assert len(meta.index) == 0
 
     # Categoricals
@@ -205,9 +212,10 @@ def test_meta_nonempty_index():
     assert type(res) is pd.RangeIndex
     assert res.name == idx.name
 
-    idx = pd.Int64Index([1], name="foo")
+    idx = pd.Index([1], name="foo", dtype="int")
     res = meta_nonempty(idx)
-    assert type(res) is pd.Int64Index
+    assert type(res) is type(idx)
+    assert res.dtype == "int64"
     assert res.name == idx.name
 
     idx = pd.Index(["a"], name="foo")
@@ -247,7 +255,7 @@ def test_meta_nonempty_index():
     assert res.ordered == idx.ordered
     assert res.name == idx.name
 
-    levels = [pd.Int64Index([1], name="a"), pd.Float64Index([1.0], name="b")]
+    levels = [pd.Index([1], name="a"), pd.Index([1.0], name="b")]
     codes = [[0], [0]]
     idx = pd.MultiIndex(levels=levels, names=["a", "b"], codes=codes)
     res = meta_nonempty(idx)
@@ -258,7 +266,7 @@ def test_meta_nonempty_index():
     assert res.names == idx.names
 
     levels = [
-        pd.Int64Index([1], name="a"),
+        pd.Index([1], name="a"),
         pd.CategoricalIndex(data=["xyx"], categories=["xyx"], name="b"),
         pd.TimedeltaIndex([np.timedelta64(1, "D")], name="timedelta"),
     ]
@@ -275,9 +283,10 @@ def test_meta_nonempty_index():
 
 
 def test_meta_nonempty_uint64index():
-    idx = pd.UInt64Index([1], name="foo")
+    idx = pd.Index([1], name="foo", dtype="uint64")
     res = meta_nonempty(idx)
-    assert type(res) is pd.UInt64Index
+    assert type(res) is type(idx)
+    assert res.dtype == "uint64"
     assert res.name == idx.name
 
 
@@ -504,3 +513,41 @@ def test_nonempty_series_nullable_float():
     ser = pd.Series([], dtype="Float64")
     non_empty = meta_nonempty(ser)
     assert non_empty.dtype == "Float64"
+
+
+def test_assert_eq_sorts():
+    df1 = pd.DataFrame({"A": np.linspace(0, 1, 10), "B": np.random.random(10)})
+    df2 = df1.sort_values("B")
+    df2_r = df2.reset_index(drop=True)
+    assert_eq(df1, df2)
+    assert_eq(df1, df2_r, check_index=False)
+    with pytest.raises(AssertionError):
+        assert_eq(df1, df2_r)
+
+
+def test_assert_eq_scheduler():
+    using_custom_scheduler = False
+
+    def custom_scheduler(*args, **kwargs):
+        nonlocal using_custom_scheduler
+        try:
+            using_custom_scheduler = True
+            return get_sync(*args, **kwargs)
+        finally:
+            using_custom_scheduler = False
+
+    def check_custom_scheduler(part: pd.DataFrame) -> pd.DataFrame:
+        assert using_custom_scheduler, "not using custom scheduler"
+        return part + 1
+
+    df = pd.DataFrame({"x": [1, 2, 3, 4]})
+    ddf = dd.from_pandas(df, npartitions=2)
+    ddf2 = ddf.map_partitions(check_custom_scheduler, meta=ddf)
+
+    with pytest.raises(AssertionError, match="not using custom scheduler"):
+        # NOTE: we compare `ddf2` to itself in order to test both sides of the `assert_eq` logic.
+        assert_eq(ddf2, ddf2)
+
+    assert_eq(ddf2, ddf2, scheduler=custom_scheduler)
+    with dask.config.set(scheduler=custom_scheduler):
+        assert_eq(ddf2, ddf2, scheduler=None)
