@@ -1,35 +1,34 @@
 import os
+import site
 import stat
 import sys
 from collections import OrderedDict
 from contextlib import contextmanager
 
 import pytest
+import yaml
 
 import dask.config
 from dask.config import (
-    update,
-    merge,
-    collect,
-    collect_yaml,
-    collect_env,
-    get,
-    ensure_file,
-    set,
-    config,
-    rename,
-    update_defaults,
-    refresh,
-    expand_environment_variables,
+    _get_paths,
     canonical_name,
-    serialize,
+    collect,
+    collect_env,
+    collect_yaml,
+    config,
     deserialize,
+    ensure_file,
+    expand_environment_variables,
+    get,
+    merge,
+    refresh,
+    rename,
+    serialize,
+    update,
+    update_defaults,
 )
-
 from dask.utils import tmpfile
 
-yaml = pytest.importorskip("yaml")
-
 
 def test_canonical_name():
     c = {"foo-bar": 1, "fizz_buzz": 2}
@@ -238,47 +237,47 @@ def test_ensure_file(tmpdir):
 
 
 def test_set():
-    with set(abc=123):
+    with dask.config.set(abc=123):
         assert config["abc"] == 123
-        with set(abc=456):
+        with dask.config.set(abc=456):
             assert config["abc"] == 456
         assert config["abc"] == 123
 
     assert "abc" not in config
 
-    with set({"abc": 123}):
+    with dask.config.set({"abc": 123}):
         assert config["abc"] == 123
     assert "abc" not in config
 
-    with set({"abc.x": 1, "abc.y": 2, "abc.z.a": 3}):
+    with dask.config.set({"abc.x": 1, "abc.y": 2, "abc.z.a": 3}):
         assert config["abc"] == {"x": 1, "y": 2, "z": {"a": 3}}
     assert "abc" not in config
 
     d = {}
-    set({"abc.x": 123}, config=d)
+    dask.config.set({"abc.x": 123}, config=d)
     assert d["abc"]["x"] == 123
 
 
 def test_set_kwargs():
-    with set(foo__bar=1, foo__baz=2):
+    with dask.config.set(foo__bar=1, foo__baz=2):
         assert config["foo"] == {"bar": 1, "baz": 2}
     assert "foo" not in config
 
     # Mix kwargs and dict, kwargs override
-    with set({"foo.bar": 1, "foo.baz": 2}, foo__buzz=3, foo__bar=4):
+    with dask.config.set({"foo.bar": 1, "foo.baz": 2}, foo__buzz=3, foo__bar=4):
         assert config["foo"] == {"bar": 4, "baz": 2, "buzz": 3}
     assert "foo" not in config
 
     # Mix kwargs and nested dict, kwargs override
-    with set({"foo": {"bar": 1, "baz": 2}}, foo__buzz=3, foo__bar=4):
+    with dask.config.set({"foo": {"bar": 1, "baz": 2}}, foo__buzz=3, foo__bar=4):
         assert config["foo"] == {"bar": 4, "baz": 2, "buzz": 3}
     assert "foo" not in config
 
 
 def test_set_nested():
-    with set({"abc": {"x": 123}}):
+    with dask.config.set({"abc": {"x": 123}}):
         assert config["abc"] == {"x": 123}
-        with set({"abc.y": 456}):
+        with dask.config.set({"abc.y": 456}):
             assert config["abc"] == {"x": 123, "y": 456}
         assert config["abc"] == {"x": 123}
     assert "abc" not in config
@@ -287,8 +286,8 @@ def test_set_nested():
 def test_set_hard_to_copyables():
     import threading
 
-    with set(x=threading.Lock()):
-        with set(y=1):
+    with dask.config.set(x=threading.Lock()):
+        with dask.config.set(y=1):
             pass
 
 
@@ -504,3 +503,44 @@ def test_config_inheritance():
         {"DASK_INTERNAL_INHERIT_CONFIG": serialize({"array": {"svg": {"size": 150}}})}
     )
     assert dask.config.get("array.svg.size", config=config) == 150
+
+
+def test__get_paths(monkeypatch):
+    # These environment variables are used by Dask's config system.
+    # We temporarily remove them to avoid interference from the
+    # machine where tests are being run.
+    monkeypatch.delenv("DASK_CONFIG", raising=False)
+    monkeypatch.delenv("DASK_ROOT_CONFIG", raising=False)
+
+    expected = [
+        "/etc/dask",
+        os.path.join(sys.prefix, "etc", "dask"),
+        os.path.join(os.path.expanduser("~"), ".config", "dask"),
+    ]
+    paths = _get_paths()
+    assert paths == expected
+    assert len(paths) == len(set(paths))  # No duplicate paths
+
+    with monkeypatch.context() as m:
+        m.setenv("DASK_CONFIG", "foo-bar")
+        paths = _get_paths()
+        assert paths == expected + ["foo-bar"]
+        assert len(paths) == len(set(paths))
+
+    with monkeypatch.context() as m:
+        m.setenv("DASK_ROOT_CONFIG", "foo-bar")
+        paths = _get_paths()
+        assert paths == ["foo-bar"] + expected[1:]
+        assert len(paths) == len(set(paths))
+
+    with monkeypatch.context() as m:
+        prefix = os.path.join("include", "this", "path")
+        m.setattr(site, "PREFIXES", site.PREFIXES + [prefix])
+        paths = _get_paths()
+        assert os.path.join(prefix, "etc", "dask") in paths
+        assert len(paths) == len(set(paths))
+
+
+def test_default_search_paths():
+    # Ensure _get_paths() is used for default paths
+    assert dask.config.paths == _get_paths()
